@@ -4,5 +4,5 @@ import qrunner
 if __name__ == '__main__':
     qrunner.main(
         platform='api',
-        base_url='https://www-pre.qizhidao.com',
+        base_url='https://www.qizhidao.com',
     )
