@@ -1,23 +1,25 @@
 import re
 import time
 from typing import Union
+
 import jmespath
-from qrunner.core.api.request import ResponseResult, HttpRequest
-from qrunner.core.web.driver import WebDriver
-from qrunner.core.h5.driver import H5Driver
-from qrunner.core.ios.driver import IosDriver
-from qrunner.utils.log import logger
-from qrunner.utils.config import config
-from qrunner.core.android.driver import AndroidDriver
 from jsonschema import validate
 from jsonschema.exceptions import ValidationError
-from qrunner.core.api.request import formatting
+
+from qrunner.core.android.driver import AndroidDriver
+from qrunner.core.api.request import HttpRequest, ResponseResult, formatting
+from qrunner.core.h5.driver import H5Driver
+from qrunner.core.ios.driver import IosDriver
+from qrunner.core.web.driver import WebDriver
+from qrunner.utils.config import config
+from qrunner.utils.log import logger
 
 
 class TestCase(HttpRequest):
     """
     测试用例基类，所有测试用例需要继承该类
     """
+
     driver: Union[AndroidDriver, IosDriver, WebDriver, H5Driver] = None
 
     # ---------------------初始化-------------------------------
@@ -40,13 +42,13 @@ class TestCase(HttpRequest):
         # 初始化driver
         platform = config.get_platform()
         # logger.info(platform)
-        if platform == 'android':
+        if platform == "android":
             serial_no = config.get_device()
             cls.driver = AndroidDriver(serial_no)
-        elif platform == 'web':
+        elif platform == "web":
             browser = config.get_browser()
             cls.driver = WebDriver(browser)
-        elif platform == 'ios':
+        elif platform == "ios":
             serial_no = config.get_device()
             cls.driver = IosDriver(serial_no)
         cls().start_class()
@@ -90,7 +92,7 @@ class TestCase(HttpRequest):
     @staticmethod
     def sleep(n: int):
         """休眠"""
-        logger.debug(f'等待: {n}s')
+        logger.debug(f"等待: {n}s")
         time.sleep(n)
 
     def screenshot(self, file_name):
@@ -113,60 +115,60 @@ class TestCase(HttpRequest):
         for _ in range(timeout + 1):
             try:
                 page_source = self.driver.get_page_content()
-                logger.info(f'断言: {page_source}\n包含 {expect_value}')
-                assert expect_value in page_source, f'页面内容不包含 {expect_value}'
+                logger.info(f"断言: {page_source}\n包含 {expect_value}")
+                assert expect_value in page_source, f"页面内容不包含 {expect_value}"
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             page_source = self.driver.get_page_content()
-            logger.info(f'断言: {page_source}\n包含 {expect_value}')
-            assert expect_value in page_source, f'页面内容不包含 {expect_value}'
+            logger.info(f"断言: {page_source}\n包含 {expect_value}")
+            assert expect_value in page_source, f"页面内容不包含 {expect_value}"
 
     def assertNotText(self, expect_value, timeout=5):
         """断言页面不包含文本"""
         for _ in range(timeout + 1):
             try:
                 page_source = self.driver.get_page_content()
-                logger.info(f'断言: {page_source}\n不包含 {expect_value}')
-                assert expect_value not in page_source, f'页面内容不包含 {expect_value}'
+                logger.info(f"断言: {page_source}\n不包含 {expect_value}")
+                assert expect_value not in page_source, f"页面内容不包含 {expect_value}"
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             page_source = self.driver.get_page_content()
-            logger.info(f'断言: {page_source}\n不包含 {expect_value}')
-            assert expect_value not in page_source, f'页面内容仍然包含 {expect_value}'
+            logger.info(f"断言: {page_source}\n不包含 {expect_value}")
+            assert expect_value not in page_source, f"页面内容仍然包含 {expect_value}"
 
     def assertElement(self, timeout=5, **kwargs):
         """断言元素存在"""
         for _ in range(timeout + 1):
             try:
                 flag = self.elem(**kwargs).exists()
-                logger.info(f'断言: 元素 {kwargs} 存在结果为 {flag}')
-                assert flag, f'元素 {kwargs} 不存在'
+                logger.info(f"断言: 元素 {kwargs} 存在结果为 {flag}")
+                assert flag, f"元素 {kwargs} 不存在"
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             flag = self.elem(**kwargs).exists()
-            logger.info(f'断言: 元素 {kwargs} 存在结果为 {flag}')
-            assert flag, f'元素 {kwargs} 不存在'
+            logger.info(f"断言: 元素 {kwargs} 存在结果为 {flag}")
+            assert flag, f"元素 {kwargs} 不存在"
 
     def assertNotElement(self, timeout=5, **kwargs):
         """断言元素不存在"""
         for _ in range(timeout + 1):
             try:
                 flag = self.elem(**kwargs).exists()
-                logger.info(f'断言: 元素 {kwargs} 存在结果为 {flag}')
-                assert not flag, f'元素 {kwargs} 仍然存在'
+                logger.info(f"断言: 元素 {kwargs} 存在结果为 {flag}")
+                assert not flag, f"元素 {kwargs} 仍然存在"
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             flag = self.elem(**kwargs).exists()
-            logger.info(f'断言: 元素 {kwargs} 存在结果为 {flag}')
-            assert not flag, f'元素 {kwargs} 仍然存在'
+            logger.info(f"断言: 元素 {kwargs} 存在结果为 {flag}")
+            assert not flag, f"元素 {kwargs} 仍然存在"
 
     # WEB专用方法
     def open(self, url=None):
@@ -195,66 +197,66 @@ class TestCase(HttpRequest):
         for _ in range(timeout + 1):
             try:
                 title = self.driver.get_title()
-                logger.info(f'断言: 页面标题 {title} 等于 {expect_value}')
-                assert expect_value == title, f'页面标题 {title} 不等于 {expect_value}'
+                logger.info(f"断言: 页面标题 {title} 等于 {expect_value}")
+                assert expect_value == title, f"页面标题 {title} 不等于 {expect_value}"
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             title = self.driver.get_title()
-            logger.info(f'断言: 页面标题 {title} 等于 {expect_value}')
-            assert expect_value == title, f'页面标题 {title} 不等于 {expect_value}'
+            logger.info(f"断言: 页面标题 {title} 等于 {expect_value}")
+            assert expect_value == title, f"页面标题 {title} 不等于 {expect_value}"
 
     def assertInTitle(self, expect_value=None, timeout=5):
         """断言页面标题包含"""
         for _ in range(timeout + 1):
             try:
                 title = self.driver.get_title()
-                logger.info(f'断言: 页面标题 {title} 包含 {expect_value}')
-                assert expect_value in title, f'页面标题 {title} 不包含 {expect_value}'
+                logger.info(f"断言: 页面标题 {title} 包含 {expect_value}")
+                assert expect_value in title, f"页面标题 {title} 不包含 {expect_value}"
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             title = self.driver.get_title()
-            logger.info(f'断言: 页面标题 {title} 包含 {expect_value}')
-            assert expect_value in title, f'页面标题 {title} 不包含 {expect_value}'
+            logger.info(f"断言: 页面标题 {title} 包含 {expect_value}")
+            assert expect_value in title, f"页面标题 {title} 不包含 {expect_value}"
 
     def assertUrl(self, expect_value=None, timeout=5):
         """断言页面url等于"""
         for _ in range(timeout + 1):
             try:
                 url = self.driver.get_url()
-                logger.info(f'断言: 页面url {url} 等于 {expect_value}')
-                assert expect_value == url, f'页面url {url} 不等于 {expect_value}'
+                logger.info(f"断言: 页面url {url} 等于 {expect_value}")
+                assert expect_value == url, f"页面url {url} 不等于 {expect_value}"
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             url = self.driver.get_url()
-            logger.info(f'断言: 页面url {url} 等于 {expect_value}')
-            assert expect_value == url, f'页面url {url} 不等于 {expect_value}'
+            logger.info(f"断言: 页面url {url} 等于 {expect_value}")
+            assert expect_value == url, f"页面url {url} 不等于 {expect_value}"
 
     def assertInUrl(self, expect_value=None, timeout=5):
         """断言页面url包含"""
         for _ in range(timeout + 1):
             try:
                 url = self.driver.get_url()
-                logger.info(f'断言: 页面url {url} 包含 {expect_value}')
-                assert expect_value in url, f'页面url {url} 不包含 {expect_value}'
+                logger.info(f"断言: 页面url {url} 包含 {expect_value}")
+                assert expect_value in url, f"页面url {url} 不包含 {expect_value}"
                 break
             except AssertionError:
                 time.sleep(1)
         else:
             url = self.driver.get_url()
-            logger.info(f'断言: 页面url {url} 包含 {expect_value}')
-            assert expect_value in url, f'页面url {url} 不包含 {expect_value}'
+            logger.info(f"断言: 页面url {url} 包含 {expect_value}")
+            assert expect_value in url, f"页面url {url} 不包含 {expect_value}"
 
     def assertAlertText(self, expect_value):
         """断言弹窗文本"""
         alert_text = self.driver.get_alert_text()
-        logger.info(f'断言: 弹窗文本 {alert_text} 等于 {expect_value}')
-        assert expect_value == alert_text, f'弹窗文本 {alert_text} 等于 {expect_value}'
+        logger.info(f"断言: 弹窗文本 {alert_text} 等于 {expect_value}")
+        assert expect_value == alert_text, f"弹窗文本 {alert_text} 等于 {expect_value}"
 
     # APP专用方法
     def install_app(self, url):
@@ -284,9 +286,10 @@ class TestCase(HttpRequest):
         断言状态码
         """
         actual_code = ResponseResult.status_code
-        logger.info(f'断言: {actual_code} 等于 {status_code}')
-        assert actual_code == status_code, \
-            f'status_code {ResponseResult} != {status_code}'
+        logger.info(f"断言: {actual_code} 等于 {status_code}")
+        assert (
+            actual_code == status_code
+        ), f"status_code {ResponseResult} != {status_code}"
 
     @staticmethod
     def assertSchema(schema, response=None) -> None:
@@ -311,8 +314,8 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {search_value} 等于 {value}')
-        assert search_value == value, f'{search_value} != {value}'
+        logger.info(f"断言: {search_value} 等于 {value}")
+        assert search_value == value, f"{search_value} != {value}"
 
     @staticmethod
     def assertEq(path, value):
@@ -321,8 +324,8 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {search_value} 等于 {value}')
-        assert search_value == value, f'{search_value} != {value}'
+        logger.info(f"断言: {search_value} 等于 {value}")
+        assert search_value == value, f"{search_value} != {value}"
 
     @staticmethod
     def assertNotEq(path, value):
@@ -331,7 +334,7 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {search_value} 不等于 {value}')
+        logger.info(f"断言: {search_value} 不等于 {value}")
         assert search_value != value, f"{search_value} 等于 {value}"
 
     @staticmethod
@@ -341,7 +344,7 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {len(search_value)} 等于 {value}')
+        logger.info(f"断言: {len(search_value)} 等于 {value}")
         assert len(search_value) == value, f"{search_value} 的长度不等于 {value}"
 
     @staticmethod
@@ -351,7 +354,7 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {len(search_value)} 大于 {value}')
+        logger.info(f"断言: {len(search_value)} 大于 {value}")
         assert len(search_value) > value, f"{search_value} 的长度不大于 {value}"
 
     @staticmethod
@@ -361,7 +364,7 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {len(search_value)} 大于等于 {value}')
+        logger.info(f"断言: {len(search_value)} 大于等于 {value}")
         assert len(search_value) >= value, f"{search_value} 的长度不大于 {value}"
 
     @staticmethod
@@ -371,7 +374,7 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {len(search_value)} 小于 {value}')
+        logger.info(f"断言: {len(search_value)} 小于 {value}")
         assert len(search_value) < value, f"{search_value} 的长度不大于 {value}"
 
     @staticmethod
@@ -381,7 +384,7 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {len(search_value)} 小于等于 {value}')
+        logger.info(f"断言: {len(search_value)} 小于等于 {value}")
         assert len(search_value) <= value, f"{search_value} 的长度不大于 {value}"
 
     @staticmethod
@@ -392,11 +395,11 @@ class TestCase(HttpRequest):
         """
         search_value = jmespath.search(path, ResponseResult.response)
         if isinstance(search_value, str):
-            if '.' in search_value:
+            if "." in search_value:
                 search_value = float(search_value)
             else:
                 search_value = int(search_value)
-        logger.info(f'断言: {search_value} 大于 {value}')
+        logger.info(f"断言: {search_value} 大于 {value}")
         assert search_value > value, f"{search_value} 不大于 {value}"
 
     @staticmethod
@@ -407,11 +410,11 @@ class TestCase(HttpRequest):
         """
         search_value = jmespath.search(path, ResponseResult.response)
         if isinstance(search_value, str):
-            if '.' in search_value:
+            if "." in search_value:
                 search_value = float(search_value)
             else:
                 search_value = int(search_value)
-        logger.info(f'断言: {search_value} 大于等于 {value}')
+        logger.info(f"断言: {search_value} 大于等于 {value}")
         assert search_value >= value, f"{search_value} 小于 {value}"
 
     @staticmethod
@@ -422,11 +425,11 @@ class TestCase(HttpRequest):
         """
         search_value = jmespath.search(path, ResponseResult.response)
         if isinstance(search_value, str):
-            if '.' in search_value:
+            if "." in search_value:
                 search_value = float(search_value)
             else:
                 search_value = int(search_value)
-        logger.info(f'断言: {search_value} 小于 {value}')
+        logger.info(f"断言: {search_value} 小于 {value}")
         assert search_value < value, f"{search_value} 不大于 {value}"
 
     @staticmethod
@@ -437,11 +440,11 @@ class TestCase(HttpRequest):
         """
         search_value = jmespath.search(path, ResponseResult.response)
         if isinstance(search_value, str):
-            if '.' in search_value:
+            if "." in search_value:
                 search_value = float(search_value)
             else:
                 search_value = int(search_value)
-        logger.info(f'断言: {search_value} 小于等于 {value}')
+        logger.info(f"断言: {search_value} 小于等于 {value}")
         assert search_value <= value, f"{search_value} 不大于 {value}"
 
     @staticmethod
@@ -451,12 +454,14 @@ class TestCase(HttpRequest):
         """
         search_value = jmespath.search(path, ResponseResult.response)
         if isinstance(search_value, str):
-            if '.' in search_value:
+            if "." in search_value:
                 search_value = float(search_value)
             else:
                 search_value = int(search_value)
-        logger.info(f'断言: {search_value} 在 [{start}, {end}] 范围内')
-        assert (search_value >= start) & (search_value <= end), f'{search_value} 不在[{start}, {end}]范围内'
+        logger.info(f"断言: {search_value} 在 [{start}, {end}] 范围内")
+        assert (search_value >= start) & (
+            search_value <= end
+        ), f"{search_value} 不在[{start}, {end}]范围内"
 
     @staticmethod
     def assertIn(path, value):
@@ -465,7 +470,7 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {search_value} 被 {value} 包含')
+        logger.info(f"断言: {search_value} 被 {value} 包含")
         assert search_value in value, f"{value} 不包含 {search_value}"
 
     @staticmethod
@@ -475,15 +480,15 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {search_value} 不被 {value} 包含')
+        logger.info(f"断言: {search_value} 不被 {value} 包含")
         assert search_value not in value, f"{value} 包含 {search_value}"
 
     @staticmethod
     def assertNotExists(path):
         """断言字段不存在"""
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {path} 不存在或值为None')
-        assert search_value is None, f'仍然包含 {path} 为 {search_value}'
+        logger.info(f"断言: {path} 不存在或值为None")
+        assert search_value is None, f"仍然包含 {path} 为 {search_value}"
 
     @staticmethod
     def assertContains(path, value):
@@ -492,7 +497,7 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {search_value} 包含 {value}')
+        logger.info(f"断言: {search_value} 包含 {value}")
         assert value in search_value, f"{search_value} 不包含 {value}"
 
     @staticmethod
@@ -502,7 +507,7 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {search_value} 不包含 {value}')
+        logger.info(f"断言: {search_value} 不包含 {value}")
         assert value not in search_value, f"{search_value} 包含 {value}"
 
     @staticmethod
@@ -512,20 +517,22 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         if not isinstance(value_type, type):
-            if value_type == 'int':
+            if value_type == "int":
                 value_type = int
-            elif value_type == 'str':
+            elif value_type == "str":
                 value_type = str
-            elif value_type == 'list':
+            elif value_type == "list":
                 value_type = list
-            elif value_type == 'dict':
+            elif value_type == "dict":
                 value_type = dict
             else:
                 value_type = str
 
         search_value = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {search_value} 是 {value_type} 类型')
-        assert isinstance(search_value, value_type), f'{search_value} 不是 {value_type} 类型'
+        logger.info(f"断言: {search_value} 是 {value_type} 类型")
+        assert isinstance(
+            search_value, value_type
+        ), f"{search_value} 不是 {value_type} 类型"
 
     @staticmethod
     def assertStartsWith(path, value):
@@ -534,8 +541,8 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value: str = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {search_value} 以 {value} 开头')
-        assert search_value.startswith(value), f'{search_value} 不以 {value} 开头'
+        logger.info(f"断言: {search_value} 以 {value} 开头")
+        assert search_value.startswith(value), f"{search_value} 不以 {value} 开头"
 
     @staticmethod
     def assertEndsWith(path, value):
@@ -544,8 +551,8 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value: str = jmespath.search(path, ResponseResult.response)
-        logger.info(f'断言: {search_value} 以 {value} 结尾')
-        assert search_value.endswith(value), f'{search_value} 不以 {value} 结尾'
+        logger.info(f"断言: {search_value} 以 {value} 结尾")
+        assert search_value.endswith(value), f"{search_value} 不以 {value} 结尾"
 
     @staticmethod
     def assertRegexMatch(path, value):
@@ -554,6 +561,6 @@ class TestCase(HttpRequest):
         doc: https://jmespath.org/
         """
         search_value = jmespath.search(path, ResponseResult.response)
-        match_obj = re.match(r'' + value, search_value, flags=re.I)
-        logger.info(f'断言: {search_value} 匹配正则表达式 {value} 成功')
-        assert match_obj is not None, f'结果 {search_value} 匹配失败'
+        match_obj = re.match(r"" + value, search_value, flags=re.I)
+        logger.info(f"断言: {search_value} 匹配正则表达式 {value} 成功")
+        assert match_obj is not None, f"结果 {search_value} 匹配失败"
