@@ -1,27 +1,26 @@
 # @Time    : 2022/2/22 9:35
 # @Author  : kang.yang@qizhidao.com
 # @File    : request.py
+import json as json_util
+import logging
 import sys
 from urllib import parse
+
 import requests
-import json as json_util
 from deepdiff import DeepDiff
 
-from qrunner.utils.json_utils import get_schema, formatting
 from qrunner.utils.config import config
+from qrunner.utils.json_utils import formatting, get_schema
 from qrunner.utils.log import logger
-import logging
 
 # 去掉requests本身的日志
-urllib3_logger = logging.getLogger('urllib3')
+urllib3_logger = logging.getLogger("urllib3")
 urllib3_logger.setLevel(logging.CRITICAL)
 
-# IMG = ["jpg", "jpeg", "gif", "bmp", "webp"]
-
 
 def request(func):
     def wrapper(*args, **kwargs):
-        logger.info('-------------- Request -----------------[🚀]')
+        logger.info("-------------- Request -----------------[🚀]")
         # 给接口带上默认域名
         try:
             path = list(args)[1]
@@ -30,16 +29,16 @@ def request(func):
 
         if "http" not in path:
             base_url = config.get_host()
-            if 'http' in base_url:
+            if "http" in base_url:
                 url = parse.urljoin(base_url, path)
                 try:
                     args_list = list(args)
                     args_list[1] = url
                     args = tuple(args_list)
                 except Exception:
-                    kwargs['url'] = url
+                    kwargs["url"] = url
             else:
-                logger.debug('请设置正确的base_url')
+                logger.debug("请设置正确的base_url")
                 sys.exit()
         else:
             url = path
@@ -50,16 +49,18 @@ def request(func):
         #     img_file = True
 
         # 请求头处理，写入登录态
-        login_status = kwargs.get('login', True)
+        login_status = kwargs.get("login", True)
         tmp_headers = config.get_login() if login_status is True else config.get_visit()
         if tmp_headers:
-            tmp_headers.update(kwargs.pop('headers', {}))
-            kwargs['headers'] = tmp_headers
+            tmp_headers.update(kwargs.pop("headers", {}))
+            kwargs["headers"] = tmp_headers
 
         # 设置默认超时时间
         timeout_config = config.get_timeout()
         timeout_user_set = kwargs.pop("timeout", None)
-        kwargs['timeout'] = timeout_user_set if timeout_user_set is not None else timeout_config
+        kwargs["timeout"] = (
+            timeout_user_set if timeout_user_set is not None else timeout_config
+        )
 
         # 获取日志需要的参数信息
         auth = kwargs.get("auth", "")
@@ -72,7 +73,9 @@ def request(func):
         r = func(*args, **kwargs)
 
         # 输出请求参数日志
-        logger.debug("[method]: {m}      [url]: {u}".format(m=func.__name__.upper(), u=url))
+        logger.debug(
+            "[method]: {m}      [url]: {u}".format(m=func.__name__.upper(), u=url)
+        )
         if auth != "":
             logger.debug(f"[auth]:\n {formatting(auth)}")
         logger.debug(f"[headers]:\n {formatting(dict(r.request.headers))}")
@@ -88,7 +91,7 @@ def request(func):
         # 保存响应结果并输出日志
         status_code = r.status_code
         headers = r.headers
-        content_type = headers.get('Content-Type')
+        content_type = headers.get("Content-Type")
         ResponseResult.status_code = status_code
         logger.info("-------------- Response ----------------")
         logger.debug(f"[status]: {status_code}")
@@ -100,7 +103,7 @@ def request(func):
             ResponseResult.response = resp
         except Exception:
             # 非json响应数据，根据响应内容类型进行判断
-            if 'text' not in content_type:
+            if "text" not in content_type:
                 logger.debug(f"[type]: {content_type}")
                 logger.debug(f"[response]:\n {r.content}")
                 ResponseResult.response = r.content
@@ -118,7 +121,6 @@ class ResponseResult:
 
 
 class HttpRequest(object):
-
     @request
     def get(self, url, params=None, login=True, **kwargs):
         # if "http" not in url:
@@ -132,21 +134,21 @@ class HttpRequest(object):
 
     def get_req_schema(self, *args, **kwargs):
         """get请求，检查多次请求返回的schema是否稳定"""
-        exclude_paths = kwargs.pop('exclude_paths', {})
-        execute_time = kwargs.pop('execute_time', 10)
+        exclude_paths = kwargs.pop("exclude_paths", {})
+        execute_time = kwargs.pop("execute_time", 10)
 
         self.get(*args, **kwargs)
         schema_start = get_schema(self.response)
         diff_result = []
 
         for i in range(execute_time):
-            logger.debug(f'第 {i+1} 次执行')
+            logger.debug(f"第 {i+1} 次执行")
             self.get(*args, **kwargs)
             schema_ = get_schema(self.response)
             result = DeepDiff(schema_start, schema_, exclude_paths=exclude_paths)
             diff_result.append(result)
 
-        logger.debug(f'diff结果:')
+        logger.debug(f"diff结果:")
         for item in diff_result:
             for item_ in item.items():
                 print(item_)
@@ -165,26 +167,25 @@ class HttpRequest(object):
 
     def post_req_schema(self, *args, **kwargs):
         """post请求，检查多次请求返回的schema是否稳定"""
-        exclude_paths = kwargs.pop('exclude_paths', {})
-        execute_time = kwargs.pop('execute_time', 10)
+        exclude_paths = kwargs.pop("exclude_paths", {})
+        execute_time = kwargs.pop("execute_time", 10)
 
         self.post(*args, **kwargs)
         schema_start = get_schema(self.response)
         diff_result = []
 
         for i in range(execute_time):
-            logger.debug(f'第 {i+1} 次执行')
+            logger.debug(f"第 {i+1} 次执行")
             self.post(*args, **kwargs)
             schema_ = get_schema(self.response)
             result = DeepDiff(schema_start, schema_, exclude_paths=exclude_paths)
             diff_result.append(result)
 
-        logger.debug(f'diff结果:')
+        logger.debug(f"diff结果:")
         for item in diff_result:
             for item_ in item.items():
                 print(item_)
 
-
     @request
     def put(self, url, data=None, json=None, login=True, **kwargs):
         # if "http" not in url:
@@ -226,12 +227,22 @@ class HttpRequest(object):
         return s
 
     @staticmethod
-    def request(method=None, url=None, headers=None, files=None, data=None,
-                params=None, auth=None, cookies=None, hooks=None, json=None):
+    def request(
+        method=None,
+        url=None,
+        headers=None,
+        files=None,
+        data=None,
+        params=None,
+        auth=None,
+        cookies=None,
+        hooks=None,
+        json=None,
+    ):
         """
         A user-created :class:`Request <Request>` object.
         """
-        req = requests.Request(method, url, headers, files, data,
-                               params, auth, cookies, hooks, json)
+        req = requests.Request(
+            method, url, headers, files, data, params, auth, cookies, hooks, json
+        )
         return req
-
