@@ -206,8 +206,7 @@ data_content = """{
 
 
 def create_scaffold(project_name, platform):
-    """ create scaffold with specified project name.
-    """
+    """create scaffold with specified project name."""
 
     def create_folder(path):
         os.makedirs(path)
@@ -222,18 +221,18 @@ def create_scaffold(project_name, platform):
 
     create_folder(project_name)
     # 新增测试用例目录
-    create_folder(os.path.join(project_name, 'test_dir'))
+    create_folder(os.path.join(project_name, "test_dir"))
     create_file(
-        os.path.join(project_name, 'test_dir', "__init__.py"),
-        '',
+        os.path.join(project_name, "test_dir", "__init__.py"),
+        "",
     )
     # 新增测试数据目录
-    create_folder(os.path.join(project_name, 'test_data'))
+    create_folder(os.path.join(project_name, "test_data"))
     create_file(
-        os.path.join(project_name, 'test_data', "data.json"),
+        os.path.join(project_name, "test_data", "data.json"),
         data_content,
     )
-    if platform == 'android':
+    if platform == "android":
         # 新增框架入口程序
         create_file(
             os.path.join(project_name, "run.py"),
@@ -241,11 +240,11 @@ def create_scaffold(project_name, platform):
         )
         # 新增安卓测试用例
         create_file(
-            os.path.join(project_name, 'test_dir', "test_android.py"),
+            os.path.join(project_name, "test_dir", "test_android.py"),
             case_content_android,
         )
 
-    elif platform == 'ios':
+    elif platform == "ios":
         # 新增框架入口程序
         create_file(
             os.path.join(project_name, "run.py"),
@@ -253,10 +252,10 @@ def create_scaffold(project_name, platform):
         )
         # 新增ios测试用例
         create_file(
-            os.path.join(project_name, 'test_dir', "test_ios.py"),
+            os.path.join(project_name, "test_dir", "test_ios.py"),
             case_content_ios,
         )
-    elif platform == 'web':
+    elif platform == "web":
         # 新增框架入口程序
         create_file(
             os.path.join(project_name, "run.py"),
@@ -264,10 +263,10 @@ def create_scaffold(project_name, platform):
         )
         # 新增web测试用例
         create_file(
-            os.path.join(project_name, 'test_dir', "test_web.py"),
+            os.path.join(project_name, "test_dir", "test_web.py"),
             case_content_web,
         )
-    elif platform == 'api':
+    elif platform == "api":
         # 新增框架入口程序
         create_file(
             os.path.join(project_name, "run.py"),
@@ -275,12 +274,9 @@ def create_scaffold(project_name, platform):
         )
         # 新增接口测试用例
         create_file(
-            os.path.join(project_name, 'test_dir', "test_api.py"),
+            os.path.join(project_name, "test_dir", "test_api.py"),
             case_content_api,
         )
     else:
-        print('请输入正确的平台: android、ios、web、api')
+        print("请输入正确的平台: android、ios、web、api")
         sys.exit()
-
-
-
