@@ -38,10 +38,10 @@ class Config:
         return self.get('common', 'base_url')
 
     def get_login(self):
-        return self.get('common', 'login_headers')
+        return self.get('common', 'login')
 
     def get_visit(self):
-        return self.get('common', 'visit_headers')
+        return self.get('common', 'visit')
 
     def get_timeout(self):
         return self.get('common', 'timeout')
