@@ -9,7 +9,7 @@ import inspect as sys_inspect
 
 
 # 报告模块
-from qrunner import logger
+from qrunner.utils.log import logger
 from qrunner.utils.config import config
 
 
